<?php
/*
+------------------------------------------------------------------------+
| ConPresso-Module "Track" File Injection Detection                      |
+------------------------------------------------------------------------+
| Copyright (c) Markus Rsel http://www.conpresso4.de                    |
+------------------------------------------------------------------------+
| LICENSE INFO                                                           |
| This source file is subject to ConPresso license version 2002-11-16    |
| that is bundled with this package in the files LICENSE_EN.TXT or       |
| LICENSE_DE.TXT, and is available through the world-wide-web at         |
|     http://www.conpresso.de/license/LICENSE_EN-2002-11-16.TXT or       |
|     http://www.conpresso.de/license/LICENSE_DE-2002-11-16.TXT          |
|                                                                        |
| If you did not receive a copy of the ConPresso license and are unable  |
| to obtain it through the world-wide-web, please send a note to         |
| <license@conpresso.de> so we can e-mail you a copy immediately.        |
+------------------------------------------------------------------------+
| MODULE LICENSE                                                         |
| This souce file is also subject to the module license available        |
| through the world-wide-web at                                          |
|    http://www.conpresso4.de/_rubric/index.php?rubric=Lizenzbedingungen |
| It is NOT freeware and must not be redistributed!                      |
+------------------------------------------------------------------------+
| Authors: Markus Rsel <mods@50n.de>                                    |
+------------------------------------------------------------------------+

Version 4.2 / December 2013

*/

define('CPO', true);
require_once('../_include/checkaccess.inc.php'); 

$directory = basename(dirname($_SERVER['PHP_SELF'])); 

require(CPO_BASEDIR.'_include/check.php');
require(CPO_BASEDIR.'_include/header.php');

printPageHeader(
    __('File upgrade check'),
    __('In this view you can detect file changes prior to a system update.')
);
include(CPO_BASEDIR.'_include/message.php');
include(CPO_BASEDIR.$activeModules['track']['directory'].'/producer.inc.php');


    echo '<h2>'.__('Additional rubric directories').'</h2>';
    $rubricDirectories = array();
    $moduleDirectories = array();
    $d = dir(CPO_BASEDIR);
    while (false!==($entry = $d->read())) {
//		echo $entry.' / ';
        if ($entry=='..') continue;
        if (!is_dir(CPO_BASEDIR.$entry) || !is_readable(CPO_BASEDIR.$entry)) continue;
        if ($entry=='_rubric') continue;
        if (file_exists(CPO_BASEDIR.$entry . '/common-module.inc.php')) {
            $moduleDirectories[] = $entry;
        } else {
			if (!file_exists(CPO_BASEDIR.$entry . '/rubric.cpo')) continue;
            echo htmlspecialchars($entry, ENT_COMPAT, 'ISO-8859-15') . '<br />';
            $rubricDirectories[] = $entry;
        }
    }
    $d->close();
//	print_r($moduleDirectories);

    echo '<br /><br /><h2>'.__('Module directories').'</h2>';
    foreach ($moduleDirectories as $directory) {
        echo htmlspecialchars($directory, ENT_COMPAT, 'ISO-8859-15') . '<br />';
    }

    echo '<br /><hr /><br />';

    echo '<h2>'.__('File integrity').'</h2>';
    echo '<p><img src="'.SKIN_URL.'sym_note.gif"> '.__('Please notice that only original ConPresso files will be checked. Modules or added files can not be checked.').'</p>';

	$noIntregrityCheck = false;
    $integrity = array(); $md5_files = array();
    if (!is_readable(CPO_BASEDIR . '_include/md5_files.inc.php')) $integrity[] = '_include/md5_files.inc.php';
    else {
        include_once(CPO_BASEDIR . '_include/md5_files.inc.php');
        foreach ($md5_files as $k=>$v) {
            if ($k=='') continue;
            if ($k=='off' && $v=='off') {
                $noIntregrityCheck = true;
                break;
            }
            if (substr($k, 0, 6)=='_setup') continue;
            if (is_dir(CPO_BASEDIR . $k)) continue;
            if (!is_readable(CPO_BASEDIR . $k)) {
                $integrity[] = $k;
                continue;
            }
            $buffer = '';
            $handle = fopen (CPO_BASEDIR . $k, 'rb');
            $buffer = fread($handle, filesize(CPO_BASEDIR . $k));
            fclose ($handle);

            if ($v!=md5($buffer)) $integrity[] = $k;

            if (substr($k, 0, 8)=='_rubric/') {
                foreach ($rubricDirectories as $rubricDirectory) {
                    $file = str_replace('_rubric/', $rubricDirectory . '/', $k);
                    if (!file_exists(CPO_BASEDIR . $file) || !is_readable(CPO_BASEDIR . $file)) continue;
                    $handle = fopen (CPO_BASEDIR . $file, 'rb');
                    $buffer = fread($handle, filesize(CPO_BASEDIR . $k));
                    fclose ($handle);
                    if ($v!=md5($buffer)) $integrity[] = $file;
                }
            }
        }
    }

    if (count($integrity)>0) {
        echo '<p>'.__('The following files do not match the original checksum and might have been changed.').'</p>';
        foreach ($integrity as $file) {
           echo $file . '<br />'; 
        }
        echo '<p><img src="'.SKIN_URL.'sym_note.gif"> '.__('Please notice that these files will be overwritten with the original files when upgrading to a newer release. The added functionality will be lost on an upgrade.').'</p>';
        echo '<p><img src="'.SKIN_URL.'sym_info.gif"> '.__('If you do not know how to upgrade the system to a newer release then please contact the manufacturer or search for a reseller!').'</p>';
    } else {
        if ($noIntregrityCheck) echo '<p>'.__('The file integrity check is disabled.').'</p>';
        else                    echo '<p>'.__('All the files match their original checksum.').'</p>';
    }



require(CPO_BASEDIR.'_include/footer.php');
?>
